# API Reference

This section contains the API reference for NeoPika's public interfaces.

## Query Builder

::: neopika.queries
    options:
      show_root_heading: true
      show_source: true

## Tables and Fields

::: neopika.terms
    options:
      show_root_heading: true
      show_source: true

## Functions

::: neopika.functions
    options:
      show_root_heading: true
      show_source: true

## Analytics

::: neopika.analytics
    options:
      show_root_heading: true
      show_source: true 